==> ikaaro-0.50.0.tar.gz: ikaaro-0.50.0/ui/tiny_mce/plugins/advlink/langs/ja_dlg.js <==
tinyMCE.addI18n('ja.advlink_dlg',{
title:"\u30EA\u30F3\u30AF\u306E\u633F\u5165/\u7DE8\u96C6",
url:"\u30EA\u30F3\u30AFURL",
target:"\u30BF\u30FC\u30B2\u30C3\u30C8",
titlefield:"\u30BF\u30A4\u30C8\u30EB",
is_email:"\u30E1\u30FC\u30EB\u30A2\u30C9\u30EC\u30B9\u304C\u5165\u529B\u3055\u308C\u307E\u3057\u305F\u3002\u30EA\u30F3\u30AF\u306Bmailto:\u3092\u4ED8\u52A0\u3057\u307E\u3059\u304B\uFF1F",
is_external:"\u30EA\u30F3\u30AF\u306Bhttp://\u3092\u4ED8\u52A0\u3057\u307E\u3059\u304B\uFF1F",
list:"\u4E00\u89A7\u304B\u3089\u9078\u3076",
general_tab:"\u4E00\u822C",
popup_tab:"\u30DD\u30C3\u30D7\u30A2\u30C3\u30D7",
events_tab:"\u30A4\u30D9\u30F3\u30C8",
advanced_tab:"\u4E0A\u7D1A\u8005\u5411\u3051",
general_props:"\u4E00\u822C",
popup_props:"\u30DD\u30C3\u30D7\u30A2\u30C3\u30D7",
event_props:"\u30A4\u30D9\u30F3\u30C8",
advanced_props:"\u4E0A\u7D1A\u8005\u5411\u3051",
popup_opts:"\u30AA\u30D7\u30B7\u30E7\u30F3",
anchor_names:"\u30A2\u30F3\u30AB\u30FC",
target_same:"\u3053\u306E\u30A6\u30A4\u30F3\u30C9\u30A6/\u30D5\u30EC\u30FC\u30E0\u3067\u958B\u304F",
target_parent:"\u89AA\u30A6\u30A4\u30F3\u30C9\u30A6/\u89AA\u30D5\u30EC\u30FC\u30E0\u3067\u958B\u304F",
target_top:"\u30C8\u30C3\u30D7\u306E\u30D5\u30EC\u30FC\u30E0\u3067\u958B\u304F",
target_blank:"\u65B0\u3057\u3044\u30A6\u30A4\u30F3\u30C9\u30A6\u3067\u958B\u304F",
popup:"Javascript\u30DD\u30C3\u30D7\u30A2\u30C3\u30D7",
popup_url:"\u30DD\u30C3\u30D7\u30A2\u30C3\u30D7URL",
popup_name:"\u30A6\u30A4\u30F3\u30C9\u30A6\u540D",
popup_return:"'return false'\u3092\u633F\u5165\u3059\u308B",
popup_scrollbars:"\u30B9\u30AF\u30ED\u30FC\u30EB\u30D0\u30FC\u3092\u8868\u793A",
popup_statusbar:"\u30B9\u30C6\u30FC\u30BF\u30B9\u30D0\u30FC\u3092\u8868\u793A",
popup_toolbar:"\u30C4\u30FC\u30EB\u30D0\u30FC\u3092\u8868\u793A",
popup_menubar:"\u30E1\u30CB\u30E5\u30FC\u30D0\u30FC\u3092\u8868\u793A",
popup_location:"\u30A2\u30C9\u30EC\u30B9\u30D0\u30FC\u3092\u8868\u793A",
popup_resizable:"\u30A6\u30A4\u30F3\u30C9\u30A6\u306E\u30B5\u30A4\u30BA\u5909\u66F4\u3092\u8A31\u53EF\u3059\u308B",
popup_dependent:"Dependent (Mozilla/Firefox\u306E\u307F)",
popup_size:"\u30B5\u30A4\u30BA",
popup_position:"\u4F4D\u7F6E (X/Y)",
id:"ID",
style:"\u30B9\u30BF\u30A4\u30EB",
classes:"\u30AF\u30E9\u30B9",
target_name:"\u30BF\u30FC\u30B2\u30C3\u30C8\u540D",
langdir:"\u6587\u7AE0\u306E\u65B9\u5411",
target_langcode:"\u30BF\u30FC\u30B2\u30C3\u30C8\u306E\u8A00\u8A9E",
langcode:"\u8A00\u8A9E\u30B3\u30FC\u30C9",
encoding:"\u30BF\u30FC\u30B2\u30C3\u30C8\u306E\u6587\u5B57\u30A8\u30F3\u30B3\u30FC\u30C7\u30A3\u30F3\u30B0",
mime:"\u30BF\u30FC\u30B2\u30C3\u30C8\u306EMIME\u30BF\u30A4\u30D7",
rel:"\u3053\u306E\u30DA\u30FC\u30B8\u306E\u30BF\u30FC\u30B2\u30C3\u30C8\u306B\u5BFE\u3059\u308B\u95A2\u4FC2",
rev:"\u30BF\u30FC\u30B2\u30C3\u30C8\u306E\u3053\u306E\u30DA\u30FC\u30B8\u306B\u5BFE\u3059\u308B\u95A2\u4FC2",
tabindex:"\u30BF\u30D6\u30A4\u30F3\u30C7\u30C3\u30AF\u30B9",
accesskey:"\u30A2\u30AF\u30BB\u30B9\u30AD\u30FC",
ltr:"\u5DE6\u304B\u3089\u53F3",
rtl:"\u53F3\u304B\u3089\u5DE6",
link_list:"\u4E00\u89A7\u304B\u3089\u9078\u3076"
});

==> ikaaro-0.61.4.tar.gz: ikaaro-0.61.4/ui/tiny_mce/plugins/advlink/langs/ja_dlg.js <==
tinyMCE.addI18n('ja.advlink_dlg',{
title:"\u30EA\u30F3\u30AF\u306E\u633F\u5165/\u7DE8\u96C6",
url:"\u30EA\u30F3\u30AFURL",
target:"\u30BF\u30FC\u30B2\u30C3\u30C8",
titlefield:"\u30BF\u30A4\u30C8\u30EB",
is_email:"\u30E1\u30FC\u30EB\u30A2\u30C9\u30EC\u30B9\u304C\u5165\u529B\u3055\u308C\u307E\u3057\u305F\u3002\u30EA\u30F3\u30AF\u306Bmailto:\u3092\u4ED8\u52A0\u3057\u307E\u3059\u304B\uFF1F",
is_external:"\u30EA\u30F3\u30AF\u306Bhttp://\u3092\u4ED8\u52A0\u3057\u307E\u3059\u304B\uFF1F",
list:"\u4E00\u89A7\u304B\u3089\u9078\u3076",
general_tab:"\u4E00\u822C",
popup_tab:"\u30DD\u30C3\u30D7\u30A2\u30C3\u30D7",
events_tab:"\u30A4\u30D9\u30F3\u30C8",
advanced_tab:"\u4E0A\u7D1A\u8005\u5411\u3051",
general_props:"\u4E00\u822C",
popup_props:"\u30DD\u30C3\u30D7\u30A2\u30C3\u30D7",
event_props:"\u30A4\u30D9\u30F3\u30C8",
advanced_props:"\u4E0A\u7D1A\u8005\u5411\u3051",
popup_opts:"\u30AA\u30D7\u30B7\u30E7\u30F3",
anchor_names:"\u30A2\u30F3\u30AB\u30FC",
target_same:"\u3053\u306E\u30A6\u30A4\u30F3\u30C9\u30A6/\u30D5\u30EC\u30FC\u30E0\u3067\u958B\u304F",
target_parent:"\u89AA\u30A6\u30A4\u30F3\u30C9\u30A6/\u89AA\u30D5\u30EC\u30FC\u30E0\u3067\u958B\u304F",
target_top:"\u30C8\u30C3\u30D7\u306E\u30D5\u30EC\u30FC\u30E0\u3067\u958B\u304F",
target_blank:"\u65B0\u3057\u3044\u30A6\u30A4\u30F3\u30C9\u30A6\u3067\u958B\u304F",
popup:"Javascript\u30DD\u30C3\u30D7\u30A2\u30C3\u30D7",
popup_url:"\u30DD\u30C3\u30D7\u30A2\u30C3\u30D7URL",
popup_name:"\u30A6\u30A4\u30F3\u30C9\u30A6\u540D",
popup_return:"'return false'\u3092\u633F\u5165\u3059\u308B",
popup_scrollbars:"\u30B9\u30AF\u30ED\u30FC\u30EB\u30D0\u30FC\u3092\u8868\u793A",
popup_statusbar:"\u30B9\u30C6\u30FC\u30BF\u30B9\u30D0\u30FC\u3092\u8868\u793A",
popup_toolbar:"\u30C4\u30FC\u30EB\u30D0\u30FC\u3092\u8868\u793A",
popup_menubar:"\u30E1\u30CB\u30E5\u30FC\u30D0\u30FC\u3092\u8868\u793A",
popup_location:"\u30A2\u30C9\u30EC\u30B9\u30D0\u30FC\u3092\u8868\u793A",
popup_resizable:"\u30A6\u30A4\u30F3\u30C9\u30A6\u306E\u30B5\u30A4\u30BA\u5909\u66F4\u3092\u8A31\u53EF\u3059\u308B",
popup_dependent:"Dependent (Mozilla/Firefox\u306E\u307F)",
popup_size:"\u30B5\u30A4\u30BA",
popup_position:"\u4F4D\u7F6E (X/Y)",
id:"ID\u5C5E\u6027",
style:"style\u5C5E\u6027",
classes:"class\u5C5E\u6027",
target_name:"\u30BF\u30FC\u30B2\u30C3\u30C8",
langdir:"\u6587\u7AE0\u306E\u65B9\u5411",
target_langcode:"\u30BF\u30FC\u30B2\u30C3\u30C8\u306E\u8A00\u8A9E",
langcode:"\u8A00\u8A9E\u30B3\u30FC\u30C9",
encoding:"\u30BF\u30FC\u30B2\u30C3\u30C8\u306E\u30A8\u30F3\u30B3\u30FC\u30C9",
mime:"\u30BF\u30FC\u30B2\u30C3\u30C8\u306EMIME\u30BF\u30A4\u30D7",
rel:"rel\u5C5E\u6027",
rev:"rev\u5C5E\u6027",
tabindex:"\u30BF\u30D6\u30A4\u30F3\u30C7\u30C3\u30AF\u30B9",
accesskey:"\u30A2\u30AF\u30BB\u30B9\u30AD\u30FC",
ltr:"\u5DE6\u304B\u3089\u53F3",
rtl:"\u53F3\u304B\u3089\u5DE6",
link_list:"\u4E00\u89A7\u304B\u3089\u9078\u3076"
});
